#
# SQL Export
# Created by Querious (1042)
# Created: 7 June 2016 at 2:09:16 PM IST
# Encoding: Unicode (UTF-8)
#


SET @PREVIOUS_FOREIGN_KEY_CHECKS = @@FOREIGN_KEY_CHECKS;
SET FOREIGN_KEY_CHECKS = 0;


DROP TABLE IF EXISTS `user_categories`;
DROP TABLE IF EXISTS `tickets`;
DROP TABLE IF EXISTS `users`;
DROP TABLE IF EXISTS `status`;
DROP TABLE IF EXISTS `settings`;
DROP TABLE IF EXISTS `priorities`;
DROP TABLE IF EXISTS `password_resets`;
DROP TABLE IF EXISTS `migrations`;
DROP TABLE IF EXISTS `email_templates`;
DROP TABLE IF EXISTS `comment_status`;
DROP TABLE IF EXISTS `comments`;
DROP TABLE IF EXISTS `categories`;


CREATE TABLE `categories` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(30) COLLATE utf8_unicode_ci NOT NULL,
  `color` varchar(10) COLLATE utf8_unicode_ci NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `categories_name_unique` (`name`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;


CREATE TABLE `comments` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `comment` text COLLATE utf8_unicode_ci NOT NULL,
  `user_id` int(10) unsigned NOT NULL,
  `ticket_id` int(10) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `comments_user_id_foreign` (`user_id`),
  KEY `comments_ticket_id_foreign` (`ticket_id`),
  CONSTRAINT `comments_ticket_id_foreign` FOREIGN KEY (`ticket_id`) REFERENCES `tickets` (`id`) ON DELETE CASCADE ON UPDATE CASCADE,
  CONSTRAINT `comments_user_id_foreign` FOREIGN KEY (`user_id`) REFERENCES `users` (`id`) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;


CREATE TABLE `comment_status` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `comment_id` int(10) unsigned NOT NULL,
  `owner_id` int(11) NOT NULL,
  `owner_status` enum('read','unread') COLLATE utf8_unicode_ci NOT NULL DEFAULT 'unread',
  `agent_id` int(11) NOT NULL,
  `agent_status` enum('read','unread') COLLATE utf8_unicode_ci NOT NULL DEFAULT 'unread',
  `admin_status` enum('read','unread') COLLATE utf8_unicode_ci NOT NULL DEFAULT 'unread',
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `comment_status_comment_id_foreign` (`comment_id`),
  CONSTRAINT `comment_status_comment_id_foreign` FOREIGN KEY (`comment_id`) REFERENCES `comments` (`id`) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;


CREATE TABLE `email_templates` (
  `id` varchar(255) COLLATE utf8_unicode_ci NOT NULL,
  `subject` varchar(255) COLLATE utf8_unicode_ci NOT NULL,
  `content` text COLLATE utf8_unicode_ci NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;


CREATE TABLE `migrations` (
  `migration` varchar(255) COLLATE utf8_unicode_ci NOT NULL,
  `batch` int(11) NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;


CREATE TABLE `password_resets` (
  `email` varchar(255) COLLATE utf8_unicode_ci NOT NULL,
  `token` varchar(255) COLLATE utf8_unicode_ci NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  KEY `password_resets_email_index` (`email`),
  KEY `password_resets_token_index` (`token`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;


CREATE TABLE `priorities` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(30) COLLATE utf8_unicode_ci NOT NULL,
  `color` varchar(10) COLLATE utf8_unicode_ci NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `priorities_name_unique` (`name`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;


CREATE TABLE `settings` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `company_name` varchar(255) COLLATE utf8_unicode_ci NOT NULL,
  `email` varchar(255) COLLATE utf8_unicode_ci NOT NULL,
  `address` varchar(255) COLLATE utf8_unicode_ci NOT NULL,
  `logo` varchar(255) COLLATE utf8_unicode_ci NOT NULL,
  `phone` varchar(255) COLLATE utf8_unicode_ci NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;


CREATE TABLE `status` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(30) COLLATE utf8_unicode_ci NOT NULL,
  `color` varchar(10) COLLATE utf8_unicode_ci NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `status_name_unique` (`name`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;


CREATE TABLE `users` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(70) COLLATE utf8_unicode_ci NOT NULL,
  `email` varchar(255) COLLATE utf8_unicode_ci NOT NULL,
  `password` varchar(60) COLLATE utf8_unicode_ci NOT NULL,
  `user_type` enum('admin','agent','user') COLLATE utf8_unicode_ci NOT NULL DEFAULT 'user',
  `last_login` datetime NOT NULL,
  `remember_token` varchar(100) COLLATE utf8_unicode_ci DEFAULT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `users_email_unique` (`email`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;


CREATE TABLE `tickets` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `subject` varchar(100) COLLATE utf8_unicode_ci NOT NULL,
  `description` varchar(500) COLLATE utf8_unicode_ci NOT NULL,
  `type` enum('opened','closed') COLLATE utf8_unicode_ci NOT NULL DEFAULT 'opened',
  `category_id` int(10) unsigned NOT NULL,
  `priority_id` int(10) unsigned NOT NULL,
  `owner_id` int(10) unsigned NOT NULL,
  `agent_id` int(10) unsigned NOT NULL,
  `status_id` int(10) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `tickets_category_id_foreign` (`category_id`),
  KEY `tickets_priority_id_foreign` (`priority_id`),
  KEY `tickets_owner_id_foreign` (`owner_id`),
  KEY `tickets_agent_id_foreign` (`agent_id`),
  KEY `tickets_status_id_foreign` (`status_id`),
  CONSTRAINT `tickets_agent_id_foreign` FOREIGN KEY (`agent_id`) REFERENCES `users` (`id`) ON DELETE CASCADE ON UPDATE CASCADE,
  CONSTRAINT `tickets_category_id_foreign` FOREIGN KEY (`category_id`) REFERENCES `categories` (`id`) ON DELETE CASCADE ON UPDATE CASCADE,
  CONSTRAINT `tickets_owner_id_foreign` FOREIGN KEY (`owner_id`) REFERENCES `users` (`id`) ON DELETE CASCADE ON UPDATE CASCADE,
  CONSTRAINT `tickets_priority_id_foreign` FOREIGN KEY (`priority_id`) REFERENCES `priorities` (`id`) ON DELETE CASCADE ON UPDATE CASCADE,
  CONSTRAINT `tickets_status_id_foreign` FOREIGN KEY (`status_id`) REFERENCES `status` (`id`) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;


CREATE TABLE `user_categories` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `user_id` int(10) unsigned NOT NULL,
  `category_id` int(10) unsigned NOT NULL,
  PRIMARY KEY (`id`),
  KEY `user_categories_user_id_foreign` (`user_id`),
  KEY `user_categories_category_id_foreign` (`category_id`),
  CONSTRAINT `user_categories_category_id_foreign` FOREIGN KEY (`category_id`) REFERENCES `categories` (`id`) ON DELETE CASCADE ON UPDATE CASCADE,
  CONSTRAINT `user_categories_user_id_foreign` FOREIGN KEY (`user_id`) REFERENCES `users` (`id`) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;




SET FOREIGN_KEY_CHECKS = @PREVIOUS_FOREIGN_KEY_CHECKS;


SET @PREVIOUS_FOREIGN_KEY_CHECKS = @@FOREIGN_KEY_CHECKS;
SET FOREIGN_KEY_CHECKS = 0;


LOCK TABLES `categories` WRITE;
ALTER TABLE `categories` DISABLE KEYS;
INSERT INTO `categories` (`id`, `name`, `color`, `created_at`, `updated_at`) VALUES 
	(1,'technical','#18cf77',NULL,NULL),
	(2,'billing','#8a1717',NULL,NULL),
	(3,'services','#8a1717',NULL,NULL);
ALTER TABLE `categories` ENABLE KEYS;
UNLOCK TABLES;


LOCK TABLES `comments` WRITE;
ALTER TABLE `comments` DISABLE KEYS;
ALTER TABLE `comments` ENABLE KEYS;
UNLOCK TABLES;


LOCK TABLES `comment_status` WRITE;
ALTER TABLE `comment_status` DISABLE KEYS;
ALTER TABLE `comment_status` ENABLE KEYS;
UNLOCK TABLES;


LOCK TABLES `email_templates` WRITE;
ALTER TABLE `email_templates` DISABLE KEYS;
INSERT INTO `email_templates` (`id`, `subject`, `content`, `created_at`, `updated_at`) VALUES 
	('close','Ticket Closed','Hello <span style="font-weight: bold;">##NAME## </span><br><br>Your ticket<strong> ##TICKETNAME##</strong> has been closed',NULL,NULL),
	('create','Ticket Created','Hello <span style="font-weight: bold;">##NAME## </span><br><br>Your ticket<strong> ##TICKETNAME##</strong> is created',NULL,NULL),
	('delete','Ticket Deleted','Hello <span style="font-weight: bold;">##NAME## </span><br><br>Your ticket<strong> ##TICKETNAME##</strong> is  deleted',NULL,NULL),
	('reopen','Ticket ReOpened','Hello mr.<span style="font-weight: bold;">##NAME## </span><br><br>Your ticket<strong> ##TICKETNAME##</strong> is reopened',NULL,NULL),
	('update','Ticket Updated','Hello <span style="font-weight: bold;">##NAME## </span><br><br>Your ticket<strong> ##TICKETNAME##</strong>were updated',NULL,NULL);
ALTER TABLE `email_templates` ENABLE KEYS;
UNLOCK TABLES;


LOCK TABLES `migrations` WRITE;
ALTER TABLE `migrations` DISABLE KEYS;
INSERT INTO `migrations` (`migration`, `batch`) VALUES 
	('2015_11_23_111313_create_database',1),
	('2015_12_18_00000_create_comment_statuses_table',1),
	('2015_12_18_034711_CreateEmailTemplatesTable',1),
	('2015_12_20_062803_add_type_to_tickets_table',1),
	('2016_04_21_130437_create_setting_table',1);
ALTER TABLE `migrations` ENABLE KEYS;
UNLOCK TABLES;


LOCK TABLES `password_resets` WRITE;
ALTER TABLE `password_resets` DISABLE KEYS;
ALTER TABLE `password_resets` ENABLE KEYS;
UNLOCK TABLES;


LOCK TABLES `priorities` WRITE;
ALTER TABLE `priorities` DISABLE KEYS;
INSERT INTO `priorities` (`id`, `name`, `color`, `created_at`, `updated_at`) VALUES 
	(1,'low','#18cf77',NULL,NULL),
	(2,'high','#8a1717',NULL,NULL),
	(3,'medium','#eb1010',NULL,NULL);
ALTER TABLE `priorities` ENABLE KEYS;
UNLOCK TABLES;


LOCK TABLES `settings` WRITE;
ALTER TABLE `settings` DISABLE KEYS;
INSERT INTO `settings` (`id`, `company_name`, `email`, `address`, `logo`, `phone`, `created_at`, `updated_at`) VALUES 
	(1,'FRticket','admin@example.com','','logo.png','00000000000',NULL,NULL);
ALTER TABLE `settings` ENABLE KEYS;
UNLOCK TABLES;


LOCK TABLES `status` WRITE;
ALTER TABLE `status` DISABLE KEYS;
INSERT INTO `status` (`id`, `name`, `color`, `created_at`, `updated_at`) VALUES 
	(1,'pending','#18cf77',NULL,NULL),
	(2,'solved','#8a1717',NULL,NULL),
	(3,'bug','#eb1010',NULL,NULL);
ALTER TABLE `status` ENABLE KEYS;
UNLOCK TABLES;


LOCK TABLES `users` WRITE;
ALTER TABLE `users` DISABLE KEYS;
INSERT INTO `users` (`id`, `name`, `email`, `password`, `user_type`, `last_login`, `remember_token`, `created_at`, `updated_at`) VALUES 
	(1,'Admin','admin@example.com','$2y$10$E9PQEfEm4/lEDHIyH/cwlOKpzlftanMnxDWOdRklNW5bgPDryRnwC','admin','0000-00-00 00:00:00',NULL,'2016-06-07 14:08:40','2016-06-07 14:08:40');
ALTER TABLE `users` ENABLE KEYS;
UNLOCK TABLES;


LOCK TABLES `tickets` WRITE;
ALTER TABLE `tickets` DISABLE KEYS;
ALTER TABLE `tickets` ENABLE KEYS;
UNLOCK TABLES;


LOCK TABLES `user_categories` WRITE;
ALTER TABLE `user_categories` DISABLE KEYS;
ALTER TABLE `user_categories` ENABLE KEYS;
UNLOCK TABLES;




SET FOREIGN_KEY_CHECKS = @PREVIOUS_FOREIGN_KEY_CHECKS;


